==> apache-empire-db-2.5.1-dist.tar.gz: apache-empire-db-2.5.1/src/empire-db-examples/empire-db-example-spring-boot/src/main/java/org/apache/empire/samples/springboot/EmpireDBConfigProperties.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.empire.samples.springboot;

import java.util.Map;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

@Configuration
@ConfigurationProperties(prefix = "empiredb")
public class EmpireDBConfigProperties {

  private String driverClass;
  private Map<String, String> driverProperties;

  public String getDriverClass() {
    return driverClass;
  }

  public Map<String, String> getDriverProperties() {
    return driverProperties;
  }

  public void setDriverClass(String driverClass) {
    this.driverClass = driverClass;
  }

  public void setDriverProperties(Map<String, String> driverProperties) {
    this.driverProperties = driverProperties;
  }
}

==> apache-empire-db-3.3.0-dist.tar.gz: apache-empire-db-3.3.0/src/empire-db-examples/empire-db-example-spring-boot/src/main/java/org/apache/empire/samples/springboot/EmpireDBConfigProperties.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.empire.samples.springboot;

import java.util.Map;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

@Configuration
@ConfigurationProperties(prefix = "empiredb")
public class EmpireDBConfigProperties {

  private String dbmsHandlerClass;
  private Map<String, String> dbmsHandlerProperties;

  public String getDbmsHandlerClass() {
    return dbmsHandlerClass;
  }

  public Map<String, String> getDbmsHandlerProperties() {
    return dbmsHandlerProperties;
  }

  public void setDbmsHandlerClass(String dbmsHandlerClass) {
    this.dbmsHandlerClass = dbmsHandlerClass;
  }

  public void setDbmsHandlerProperties(Map<String, String> dbmsHandlerProperties) {
    this.dbmsHandlerProperties = dbmsHandlerProperties;
  }
}
